package com.tzld.piaoquan.content.understanding.service.impl;

import com.alibaba.fastjson.JSON;
import com.tzld.piaoquan.content.understanding.common.enums.ContentTypeEnum;
import com.tzld.piaoquan.content.understanding.model.param.ActionParam;
import com.tzld.piaoquan.content.understanding.model.param.GeminiParam;
import com.tzld.piaoquan.content.understanding.service.Action;
import com.tzld.piaoquan.content.understanding.util.HttpClientUtil;
import com.tzld.piaoquan.content.understanding.util.HttpPoolClient;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.concurrent.ThreadLocalRandom;

/**
 * @author supeng
 */
@Service(value = "geminiGenerateContentAction")
public class GeminiGenerateContentAction implements Action {

    @Value("${native.openai.url:http://openai.piaoquantv.com/aigc-server/gemini/generateContent}")
    private String geminiApiUrl;

    @Value("#{'${gemini:apikey:list}'.split(',')}")
    private List<String> apiKeyList;

    private static final HttpPoolClient httpPoolClient = HttpClientUtil.create(3000, 600000, 50, 200, 0, 3000);

    private static final String MODEL = "gemini-2.0-flash";
    private static final Double TEMPERATURE = 1.0;

    @Override
    public String execute(ActionParam param) {
        Integer type = param.getType();
        ThreadLocalRandom random = ThreadLocalRandom.current();
        int index = random.nextInt(apiKeyList.size());
        String apiKey = apiKeyList.get(index);
        GeminiParam geminiParam = new GeminiParam();
        geminiParam.setType(type);
        geminiParam.setPrompt(param.getPrompt());
        if (Objects.equals(ContentTypeEnum.IMAGE.getValue(), type) || Objects.equals(ContentTypeEnum.VIDEO.getValue(), type)) {
            geminiParam.setMediaUrl(param.getInput());
        }
        geminiParam.setApiKey(apiKey);
        geminiParam.setModel(MODEL);
        geminiParam.setTemperature(TEMPERATURE);
        Optional<String> optionalS = httpPoolClient.postJson(geminiApiUrl, JSON.toJSONString(geminiParam));
        if (optionalS.isPresent()) {
            String content = optionalS.get();
            //过滤一些特殊格式
            content = content.replace("```json", "").replace("```", "");
            return content;
        }
        return null;
    }
}
